import request, { postBlob, getBlob, handleImport } from '@/utils/request'

export function esGoodsList(data) {
  return request({
    url: `/es/goods/list?moduleId=${data.moduleId}`,
    method: 'post',
    data
  })
}

export function esGoodsListExport(data, name) {
  return postBlob({
    url: '/es/goods/list/export',
    data,
    name
  })
}

export function esGoodsUpdate(data) {
  return request({
    url: '/es/goods/update',
    method: 'post',
    data: data
  })
}

export function esGoodsDetail(params) {
  return request({
    url: '/es/goods/detail',
    method: 'post',
    params
  })
}

export function esGoodsDel(params) {
  return request({
    url: '/es/goods/del',
    method: 'post',
    params
  })
}

export function esGoodsCopy(params) {
  return request({
    url: '/es/goods/copy',
    method: 'post',
    params
  })
}

export function esGoodsBatchUpdateStatus(params) {
  return request({
    url: '/es/goods/batch/update/status',
    method: 'post',
    params
  })
}

export function esGoodsTop(params) {
  return request({
    url: '/es/goods/top',
    method: 'post',
    params
  })
}

export function esGoodsReply(params) {
  return request({
    url: '/es/goods/reply',
    method: 'post',
    params
  })
}
